/**
 * Test for inheritance.
 * Runs with mocha.
 */

'use strict'

const apeman = require('apeman')
const mkdirp = require('mkdirp')
const fs = require('fs')
const assert = require('assert')

describe('inherit', () => {
  let mockApemanfile = require.resolve('../doc/mocks/mock-Apemanfile.js')
  let $cwd = require(mockApemanfile).$cwd

  before((done) => {
    mkdirp($cwd, done)
  })

  before((done) => {
    fs.writeFile(
      `${$cwd}/Apemanfile.js`,
      `exports.$parent='${mockApemanfile}';exports.$ctx={};exports.$wtchs={}`,
      done
    )
  })

  it('Show tmpls.', (done) => {
    apeman.show('tmpls', {
      keysonly: true,
      configuration: mockApemanfile
    }).then(() => {
      done()
    }).catch((err) => {
      assert.ifError(err)
    })
  })

  it('Show tasks.', (done) => {
    apeman.show('tasks', {
      keysonly: true,
      configuration: mockApemanfile
    }).then(() => {
      done()
    }).catch((err) => {
      assert.ifError(err)
    })
  })

  it('Run tmpls.', (done) => {
    apeman.tmpl({
      configuration: mockApemanfile
    }).then(() => {
      done()
    }).catch((err) => {
      assert.ifError(err)
    })
  })

  it('Run mkdir tasks.', (done) => {
    apeman.task('app:mkdir', {
      configuration: mockApemanfile
    }).then(() => {
      done()
    }).catch((err) => {
      assert.ifError(err)
    })
  })

  it('Run render tasks.', (done) => {
    apeman.task('app:render', {
      configuration: mockApemanfile
    }).then(() => {
      done()
    }).catch((err) => {
      assert.ifError(err)
    })
  })

  it('Run fmt tasks.', (done) => {
    apeman.task('app:fmt', {
      configuration: mockApemanfile
    }).then(() => {
      done()
    }).catch((err) => {
      assert.ifError(err)
    })
  })

  it('List watch tasks.', (done) => {
    apeman.task('wtch:list', {
      configuration: mockApemanfile
    }).then(() => {
      done()
    }).catch((err) => {
      assert.ifError(err)
    })
  })
})

/* global describe, before, after, it */
